/*********************************************************************************
*
*	File: image.h
* Copyright(c) Andreas Magnusson 2002
*
*
*	DISCLAIMER AND STUFF:
*	This source-code is supplied AS IS. I cannot be held responsible for any damage caused
*	by use or misuse of this source-code nor any derivatives of it.
*	So use the code as you please, but give credit where they are due.
*
*********************************************************************************/
#ifndef __IMAGE_H__
#define __IMAGE_H__

#include "generic_factory.h"
#include "handle.h"

enum IMAGE_COLOR_DEPTH {IMAGE_2_BITS = 2, IMAGE_4_BITS = 4, IMAGE_8_BITS = 8,
											IMAGE_16_BITS = 16, IMAGE_24_BITS = 24, IMAGE_32_BITS = 32};

class image : public ref_counted
{
	void operator =(const image &img); // not implemented on purpose!
protected:
	int width, height, color_depth;
	unsigned char *buffer;
public:
	image();
	image(const image &img);
	virtual ~image();
	//
	virtual unsigned char *get_bits() const {return buffer;}
	virtual int get_width() const {return width;}
	virtual int get_height() const {return height;}
	virtual int get_color_depth() const {return color_depth;}
	virtual bool copy(const image &img);
	//
	virtual bool load(const std::string &file_name) = 0;
	virtual bool save(const std::string &file_name) = 0;
	virtual const char *get_type() = 0;
};

typedef handle<image> image_hnd;
typedef generic_factory<image> image_factory;
image_hnd load_image(const std::string &file_name);
bool save_image(const std::string &file_name, image_hnd &img);

#endif

